//###################################################################################
// File: doscopy1.c
//
// Eine 3.4MB groe Datei 0.txt schreiben.
// Danach diese Datei in 1.txt kopieren.
//
// Bei ATMega32 MUSS der FAT-Buffer deaktiviert werden. Siehe mydefs.h
//
// MAX_OPEN_FILE in dos.h muss >=2 sein !
//
//#########################################################################
// Last change: 21.02.2007
//#########################################################################
// hk@holger-klabunde.de
// http://www.holger-klabunde.de/index.html
//#########################################################################
// Compiler: AVR-GCC 3.4.3
//#########################################################################
#include <avr/io.h>
#include <avr/interrupt.h>
#include <stdarg.h>
#include <string.h>
#include <stdlib.h>

#include "mydefs.h"
#include "protos.h"
#include "../lcd.h"
#include "../dos.h"
#include "../printf.h"
#include "../serial.h"

//"volatile" fr alle Variablen die in Interrupt's gendert werden
unsigned int volatile countclock;

//###################################################################################
// timeout not used !
// interrupt every 47.4ms  @ 11.0592MHz
// interrupt every 32.77ms @ 16.0000MHz
SIGNAL(SIG_OVERFLOW1)        // signal handler for timer1 overflow interrupt
//###################################################################################
{
 countclock++;
}

//###################################################################################
/* Hauptprogramm */
int main(void)
//###################################################################################
{
 unsigned char result;
 
 DDRA=0; 	//Alles Eingnge
 PORTA=0xFF; 	//Eingnge mit Pullups setzen

 SFIOR&=!(1<<PUD); 	//Pullups Enable
// SFIOR=0; 	//Pullups Enable

#ifdef MMC_CARD_SPI
 MMC_IO_Init();
#endif

 ser_init();
 LCDInit();

//Timer1
 TCCR1A=0; 
 TCCR1B=0x02;        //Timer1 Start Takt = F/8 => 47.4ms at 11.059MHz
 TIMSK=(1<<TOIE1);   // enable timer1 int

 sei();              //enable interrupts

 LCDCls();
 puts("FAT DOS-Copy-Test1");
 LCDPos(2,1);
 puts("by Holgi");
 Delay1ms(1000);
 LCDCls();

 if(GetDriveInformation()!=F_OK) // get drive parameters
  {
   LCDCls();
   puts("Flash meldet sich nicht !");
   while(1);
  }
  
 RED_ON();
 GREEN_OFF();

 countclock=0;
 
 char f_id0,f_id1;
 unsigned int i;
 unsigned char buf[32];

// ca. 3.4MB Daten in eine Datei 0.txt schreiben
 result=F_OK;
 f_id0=Fopen("0.txt",F_WRITE);
 if(f_id0>=0)
  {
   for(i=0; i<65535; i++)
    {
     if(Fwrite("Hello World. Hello World. Hello World. Hello World.\n",52,f_id0)!=52) break;
    } 
   Fclose(f_id0);
  }

// Datei 0.txt in Datei 1.txt kopieren
 f_id0=Fopen("0.txt",F_READ);
 f_id1=Fopen("1.txt",F_WRITE);

 if(f_id0>=0 && f_id1>=0)
  {
   do
    {
     i=Fread(buf,32,f_id0);
     i=Fwrite(buf,i,f_id1);
    }while(i>0);
    
   Fclose(f_id0);
   Fclose(f_id1);
  }

 GREEN_ON();
 RED_OFF();
 cli(); // Disable interrupts

 LCDPos(2,1);
 printf("%d\n",countclock);
 
 for(;;) // loop forever
  {
  }
}

